# `relationalai.clients`

The `relationalai.clients` namespace contains modules for supported data platforms,
such as [Snowflake](https://www.snowflake.com/).

- [`clients.snowflake`](./snowflake/README.md)
  - [`clients.snowflake.PrimaryKey`](./snowflake/PrimaryKey.md)
  - [`clients.snowflake.Snowflake`](./snowflake/Snowflake.md)
  - [`clients.snowflake.SnowflakeTable`](./snowflake/SnowflakeTable/README.md)
    - [`clients.snowflake.SnowflakeTable.describe()`](./snowflake/SnowflakeTable/describe.md)
    - [`clients.snowflake.SnowflakeTable.fqname()`](./snowflake/SnowflakeTable/fqname.md)
    - [`clients.snowflake.SnowflakeTable.namespace()`](./snowflake/SnowflakeTable/namespace.md)
